# dearAJ

Data analysis tool for Korean National Assembly

- Installation
- Usage
  - Conference
  - Conferences
  - get_conferences_of(nth: int, save: bool, to: str, sleep: Union[float, int])
- Details
- License

## Install

## Usage

## Details

## License

Copyright Anji Wong, 2022.

Distributed under the terms of the Apache 2.0 license.
